@@ -20,7 +20,6 @@ from phootonics_controller.base_controllers.config import VCM_PORT, CAVITY1_INDE
 from phootonics_controller.base_controllers.stage_mock import MockStageController
 from phootonics_controller.base_controllers.xc_controller import ECController, MockECController
 from phootonics_controller.base_controllers.stage_vcm import VCMirrorController
-from phootonics_controller.utils.ADC_converter.ADS1263 import ADS1263_CMD
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -39,24 +38,15 @@ def ignore_exception(f):
 class ADCDevice:
 
     def __init__(self):
-        from phootonics_controller.utils.ADC_converter import ADS1263
-        self._adc = ADS1263.ADS1263()
+        from phootonics_controller.utils.adhat.ADS1263 import ADS1263
+        self._adc = ADS1263()
+        self.adcSps = 'ADS1263_38400SPS'
 
     def initialise(self):
-        if self._adc.ADS1263_init() == -1:
-            pass
-
-    def read(self):
-        try:
-            adc_value = self._adc.ADS1263_GetAll()
-            if adc_value[ADC_CHANNEL] >> 31 == 1:
-                value = REF * 2 - adc_value[ADC_CHANNEL] * REF / 0x80000000
-            else:
-                value = adc_value[ADC_CHANNEL] * REF / 0x7fffffff  # 32bit
-            return value
-        except Exception as e:
-            logger.error('could not read ADC value {}'.format(e))
-            self._adc.ADS1263_Exit()
+        if self._adc.ADS1263_init_ADC1(self.adcSps) == -1:
+            raise RuntimeError('cannot initialize ADC')
+        self._adc.ADS1263_SetMode(0)
+        self._adc.ADS1263_GetAll()
 
     def read_fast(self):
         try:
